
<html>

	<head>
		<title> GatherOS </title>

		<script type="text/javascript" src="{{ url_for('static', filename='bootstrap.min.js') }}"></script>

		<link title="no title" media="all" charset="utf-8" href="{{ url_for('static', filename='bootstrap.min.css') }}" rel="stylesheet" type="text/css">

	</head>


	<body bgcolor="">
		
	<table border="0" width="100%" height="100%">

	<tr height="10%">
	<td width="20%">
		<h3 align="center">GatherOS</h3>
		<h6 align="center"><a href="https://github.com/operatorequals/gatheros"> Github repo </a></h6>
	</td>

	<td align="left">
		<table>
		<tr>
			<td width="50%" height="10" >
								<!-- System Metadata -->
<!-- 			<table border="1">	
				{% for comm in tagged %}
			<tr>
					<td>{{ comm[1]['command'] }}:</td>
					<td>
					{% if comm[1]['response'] %}	<b> {{ comm[1]['response'] }} </b> 
					{% else %} N/A
				{% endif %}</td>
			</tr>
				{% endfor %}
			</table>
			 -->
			 					<!-- Scenario Metadata -->
<!--
 			<table border="1">		
	 			{% for k, v in metadata %}
				<tr>
					<td>{{ k }}: </td>
					<td align="center"> {% if k == 'reference' %} <a href="{{ v }}"> {% else %}  {{ v }}	{% endif %}</td>
				</tr>
 			{% endfor %}
 			</table>
 			</td>
 -->


			<td width="20%" align="center"> <!-- Meta Data -->
			{% if os == 'windows' %}
				<img src="{{ url_for('static', filename='windows_logo.png') }}" width="48px" height="48px">
			{% elif os == 'linux' %}
				<img src="{{ url_for('static', filename='linux_logo.png') }}" width="48px" height="48px">

			{% endif %}
			</td>
			<td align="right" width="30%"> <!-- Search Button -->
				<form action="search/" method="post">
				<input name="keyword" type="text">
				<input  type="submit" value="Search">
				</form>
			</td>
		</tr>
		</table>

	</td>
	</tr>

	<tr height="90%">
	<td>
		<table border="1" width="100%" height="100%">
		{% for group in commandGroups %}

		<tr >	<!-- Groups -->
			<td  >
				<a href="/command/{{ group[0] }}" target="commands-frame"> {{ group[1]['name'] }} </a>
			</td>

		</tr>
		{% endfor %}


		</table>
	</td>

	<td  height="100%" width="80%">
		<iframe width="100%" height="100%" src="/command/{{ commandGroups[0][0] }}" name="commands-frame"> </iframe>
	</td>

	</tr>


	</table>

	</body>
</html>